@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -56,7 +56,7 @@ DefaultAction.prototype.beginEvent = function() {
     this.d2Model = RVector.invalid;
     this.d2Screen = RVector.invalid;
     this.di = this.getDocumentInterface();
-    this.document = this.getDocument();
+    this.document = this.di.getDocument();
     this.setState(DefaultAction.State.Neutral);
     this.blockRefId = RObject.INVALID_ID;
     this.entityInBlockId = RObject.INVALID_ID;
@@ -286,8 +286,6 @@ DefaultAction.prototype.mouseReleaseEvent = function(event) {
             entityId = this.getEntityId(event, false, true);
 
             //qDebug("entityId: ", entityId);
-            //var e = this.document.queryEntity(entityId);
-            //if (!isNull(e)) qDebug("parentId: ", e.getParentId());
 
             if (entityId !== -1) {
                 if (shiftPressed && this.document.isSelected(entityId)) {
@@ -646,10 +644,14 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
         }
         */
 
+        // block editing with double click might be disabled globally:
         if (RSettings.getBoolValue("GraphicsView/DoubleClickEditBlock", true)===true) {
-            include("scripts/Block/Block.js");
-            EAction.handleUserMessage(qsTr("Editing block '%1'<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()));
-            Block.editBlock(this.di, entity.getReferencedBlockName());
+            // block editing with double click might be disabled for this entity:
+            if (entity.getCustomBoolProperty("QCAD", "DoubleClickEditBlock", true)===true) {
+                include("scripts/Block/Block.js");
+                EAction.handleUserMessage(qsTr("Editing block '%1'<br>Choose <i>Block > Return to Main Drawing</i> when done").arg(entity.getReferencedBlockName()), false);
+                Block.editBlock(this.di, entity.getReferencedBlockName());
+            }
         }
     }
     else if (isHatchEntity(entity)) {
